
#################################################################################
# PrimeTime Reference Methodology Script
# Script: pt.tcl
# Version: D-2010.06 (July 6, 2010)
# Copyright (C) 2008-2010 Synopsys All rights reserved.
################################################################################

# Please do not modify the sdir variable.
# Doing so may cause script to fail.
set sdir "." 

##################################################################
#    Source common and pt_setup.tcl File                         #
##################################################################

source $sdir/rm_setup/common_setup.tcl
source $sdir/rm_setup/pt_setup.tcl

# make REPORTS_DIR
file mkdir $REPORTS_DIR


##################################################################
#    Search Path, Library and Operating Condition Section        #
##################################################################

# Under normal circumstances, when executing a script with source, Tcl
# errors (syntax and semantic) cause the execution of the script to terminate.
# Uncomment the following line to set sh_continue_on_error to true to allow 
# processing to continue when errors occur.
#set sh_continue_on_error true 


  

set report_default_significant_digits 3 ;
set sh_source_uses_search_path true ;
set search_path ". $search_path" ;


##################################################################
#    Netlist Reading Section                                     #
##################################################################

set link_path "* $link_path"

read_verilog $NETLIST_FILES

current_design $DESIGN_NAME 
link 



##################################################################
#    Back Annotation Section                                     #
##################################################################

if { [info exists PARASITIC_PATHS] && [info exists PARASITIC_FILES] } {
foreach para_path $PARASITIC_PATHS para_file $PARASITIC_FILES {
   if {[string compare $para_path $DESIGN_NAME] == 0} {
      read_parasitics -increment -format sbpf $para_file 
   } else {
      read_parasitics -path $para_path -increment -format sbpf $para_file 
   }
}
}
report_annotated_parasitics -check > $REPORTS_DIR/${DESIGN_NAME}_report_annotated_parasitics.report 

##################################################################
#    Reading Constraints Section                                 #
##################################################################
if  {[info exists CONSTRAINT_FILES]} {
        foreach constraint_file $CONSTRAINT_FILES {
                if {[file extension $constraint_file] eq ".sdc"} {
                        read_sdc -echo $constraint_file
                } else {
                        source -echo $constraint_file
                }
        }
}





##################################################################
#    Clock Tree Synthesis Section                                #
##################################################################

set_propagated_clock [all_clocks] 

##################################################################
#    Update_timing and check_timing Section                      #
##################################################################


update_timing -full

# Ensure design is properly constrained
check_timing -verbose > $REPORTS_DIR/${DESIGN_NAME}_check_timing.report



##################################################################
#    Report_timing Section                                       #
##################################################################
report_timing -slack_lesser_than 0.0 -delay min_max -nosplit -input -net -sign 4 > $REPORTS_DIR/${DESIGN_NAME}_report_timing.report
report_clock -skew -attribute > $REPORTS_DIR/${DESIGN_NAME}_report_clock.report 
report_analysis_coverage > $REPORTS_DIR/${DESIGN_NAME}_report_analysis_coverage.report




